library sc_alert_dialog;

import 'package:flutter/material.dart';
import 'package:sc_alert_dialog/widget/sc_alert_checkbox.dart';
import 'package:sc_alert_dialog/widget/sc_alert_customwidget.dart';
import 'package:sc_alert_dialog/widget/sc_alert_message.dart';
import 'package:sc_alert_dialog/widget/sc_alert_radiobutton.dart';
import 'package:sc_alert_dialog/widget/sc_alert_textfield.dart';

import 'model/sc_alert_model.dart';

enum SCAlertType {
  info,
  buttons,
  loginform,
  checkbox,
  radiobutton,
  custom,
}

class SCAlertDialog {
  static Future show({
    required BuildContext context,
    String? title,
    String? message,
    Color titleTxtColor = Colors.black,
    Color messageTxtColor = Colors.black,
    Color closeBtnColor = Colors.black,
    required SCAlertType type,
    bool barrierDismissible = false,
    ValueChanged<String>? onOkBtnTap,
    String okBtnText = "OK",
    Color okBtnColor = const Color(0xFF50A1FF),
    Color okBtnTxtColor = Colors.white,
    ValueChanged<String>? onCancelBtnTap,
    String cancelBtnText = "CANCEL",
    Color cancelBtnColor = const Color(0xFFEAECF0),
    Color cancelBtnTxtColor = Colors.black,
    bool showCancelBtn = false,
    double borderRadius = 5.0,
    ValueChanged<String>? onEmailTextFieldChanged,
    ValueChanged<String>? onPasswordTextFieldChanged,
    Widget? customWidget,
    Map<String, bool>? checkBoxAry,
    ValueChanged<Map<String, bool>>? onCheckBoxSelection,
    Map<String, int>? radioButtonAry,
    ValueChanged<String>? onRadioButtonSelection,
  }) {
    // 1
    // Default Child
    Widget defaultChild = AlertDialog(
      contentPadding: EdgeInsets.zero,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(borderRadius),
      ),
      content: Container(),
    );

    // 2
    // Assing the value to the model
    SCAlertModel scAlertModel = SCAlertModel(
        title: title,
        message: message,
        titleTxtColor: titleTxtColor,
        messageTxtColor: messageTxtColor,
        closeBtnColor: closeBtnColor,
        type: type,
        barrierDismissible: barrierDismissible,
        onOkBtnTap: onOkBtnTap,
        okBtnText: okBtnText,
        okBtnColor: okBtnColor,
        okBtnTxtColor: okBtnTxtColor,
        onCancelBtnTap: onCancelBtnTap,
        cancelBtnText: cancelBtnText,
        cancelBtnColor: cancelBtnColor,
        cancelBtnTxtColor: cancelBtnTxtColor,
        showCancelBtn: showCancelBtn,
        borderRadius: borderRadius,
        onEmailTextFieldChanged: onEmailTextFieldChanged,
        onPasswordTextFieldChanged: onPasswordTextFieldChanged,
        customWidget: customWidget,
        checkBoxAry: checkBoxAry,
        onCheckBoxSelection: onCheckBoxSelection,
        radioButtonAry: radioButtonAry,
        onRadioButtonSelection: onRadioButtonSelection);

    return showGeneralDialog(
        barrierColor: Colors.black.withOpacity(0.5),
        transitionDuration: Duration(milliseconds: 200),
        barrierDismissible: barrierDismissible,
        barrierLabel: '',
        context: context,
        pageBuilder: (context, anim1, anim2) {
          switch (type) {
            case SCAlertType.info:
            case SCAlertType.buttons:
              return SCAlertMessage(model: scAlertModel);
              break;
            case SCAlertType.loginform:
              return SCAlertTextField(model: scAlertModel);
            case SCAlertType.custom:
              return SCAlertCustomWidget(model: scAlertModel);
            case SCAlertType.checkbox:
              return SCAlertCheckbox(model: scAlertModel);
            case SCAlertType.radiobutton:
              return SCAlertRadioButton(model: scAlertModel);
            default:
              return defaultChild;
          }
        });
  }
}
